package org.nst.pasientlink.authenticator.admin.command;

/**
 * <p>Title: Command </p>
 * <p>Description: Base class for commands. Implements functionality common to commands.
 * Based on Velocity forumdemo code.</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: Norwegian Centre for Telemedicine</p>
 * @author Thomas Strandens, Per Atle Bakkevoll
 * @version 1.0
 *
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "The Jakarta Project", "Jakarta-Regexp", and "Apache Software
 *    Foundation" must not be used to endorse or promote products derived
 *    from this software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache"
 *    nor may "Apache" appear in their names without prior written
 *    permission of the Apache Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.velocity.context.Context;
import org.nst.pasientlink.authenticator.admin.Controller;
import org.nst.pasientlink.authenticator.AuthenticatorStorage;
import org.nst.pasientlink.authenticator.Utility;

abstract class Command
{
    // common instance variables
    protected HttpServletRequest request = null;
    protected HttpServletResponse response = null;
    protected HttpSession mySession = null;

    // common context variable names
    public static final String DATE_FORMATTER = "dateFormatter";
    public static final String RETURN_VALUE = "returnValue";
    public static final String COMMAND = "command";

    // common request parameter names
    public static final String COMMAND_PARAMETER = "command";

    /**
     * Constructor
     */

    public Command( HttpServletRequest req, HttpServletResponse resp )
    {
        this.request=req;
        this.response=resp;
        this.mySession = req.getSession(true);
        this.setCommonResponseHeaders();
    }

    /**
     * Implemented by classes that extends this class
     *
     * @param the context
     * @return the name of the template to execute
     */

    public abstract String exec(Context context);

    /**
     * setCommonReponseHeaders sets response headers
     * common to all response generated by commands (and subclasses)
     *
     */

   private void setCommonResponseHeaders() {
      this.response.setHeader("Cache-Control","no-cache"); //HTTP 1.1
      this.response.setHeader("Pragma","no-cache"); //HTTP 1.0
      this.response.setDateHeader ("Expires", 0); //prevents caching at the proxy server
   }

   /**
    * getAuthenticatorStorage returns the authenticatorstorage from the Controller
    *
    * @return AuthenticatorStorage
    */

   public static AuthenticatorStorage getAuthenticatorStorage() {
      return Controller.getAuthenticatorStorage();
   }

   /**
    * getUtility returns the utility instance from the Controller
    */

   public static Utility getUtility() {
      return Controller.getUtility();
   }

}

