package org.nst.pasientlink.authenticator;

/**
 * <p>Title: TestAuthenticatorStorage  </p>
 * <p>Description: unit tests for authenticator storage.</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: Norwegian Centre for Telemedicine</p>
 * @author Thomas Strandens
 * @version 1.0
 */

import junit.framework.*;
import java.util.Properties;
import java.io.InputStream;
import java.io.IOException;

public class TestAuthenticatorStorage extends TestFixture {

  public TestAuthenticatorStorage(String s) {
    super(s);
  }

  public void setUp() {
   super.setUp();
  }

  public void tearDown() {
   removeTestUser();
   super.tearDown();
  }

  /**
   * testCreateuser tests create and delete user functionality
   */

   public void testCreateUser() {
      assertTrue("Failed to create test user ",
                  createTestUser());
      assertTrue("Test user does not exist",
                  this.getAuthenticatorStorage().userExists(this.getTestUserID()));
      assertEquals("Wrong test user GSM subscriber ID ",
                    this.getAuthenticatorStorage().getGSMSubscriberID(this.getTestUserID()), this.getTestUserGSMSubscriberID());
      assertTrue("Wrong test user password hash",
                  this.getUtility().verifyPasswordHash(this.getTestUserID(), this.getTestUserPasswordHash()));

   }

   /**
    * testRemoveUser creates a user then verfies that the user may be removed.
    * It then recreates the user, so that the tearDown method will have someone to kill...
    */

   public void testRemoveUser() {
      this.createTestUser();
      assertTrue("Unable to remove test user",
                  removeTestUser());
      this.createTestUser();
   }

   /**
    * testChangePassword creates a user, changes the password then checks that the
    * user may be logged in using the new password
    */

   public void testChangePassword() {
      String newPassword = "DrMABUSE2002";
      byte[] newPasswordHash = this.getUtility().hashString(newPassword);
      this.createTestUser();
      assertTrue("Unable to change testuser password", this.getAuthenticatorStorage().changePassword(this.getTestUserID(), newPasswordHash));
      assertTrue("Password check fails with changed password", this.getUtility().verifyPasswordHash(this.getTestUserID(), newPasswordHash));
   }
}
