package org.nst.pasientlink.authenticator;

/**
 * <p>Title: TestUtil  </p>
 * <p>Description: unit tests for Utility class</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: Norwegian Centre for Telemedicine</p>
 * @author Thomas Strandens
 * @version 1.0
 */

import junit.framework.*;
import org.nst.pasientlink.authenticator.*;

public class TestUtility extends TestFixture {

   public TestUtility(String s) {
      super(s);
   }

   protected void setUp() {
      super.setUp();
   }

   protected void tearDown() {
      super.tearDown();
   }

   /**
    * testByteArrayCompare simple test to verify that this stuffer works
    */

   public void testByteArrayCompare() {
      String myString = "It ain't gonna hurt now, if you open up your eyes";
      byte[] a = myString.getBytes();
      byte[] b = myString.getBytes();
      assertTrue("Byte array comparison failed", this.getUtility().byteArrayCompare(a, b));
   }

   /**
    * testHashString compares the hashes generated by the Utility class,
    * and the hardcoded hash value stored in the fixture superclass
    */

   public void testHashString() {
      byte[] myHashedPassword = this.getUtility().hashString(this.getTestUserPasswordPlaintext());
      assertTrue("Failed to generate correct password hash",
         this.getUtility().byteArrayCompare(myHashedPassword, this.getTestUserPasswordHash()));
   }

   /**
    * verify single use password generation. should not be null, should be a certain
    * number of characters and should be parsable as an integer.
    *
    */

   public void testGenerateSingleUsePassword() {
      String mySingleUsePassword = this.getUtility().generateSingleUsePassword();
      System.out.println(mySingleUsePassword);
      assertNotNull("Unable to generate single use password", mySingleUsePassword);
      this.assertEquals("Single use password has wrong length", this.getUtility().getSingleUsePasswordLength(), mySingleUsePassword.length());
      Integer mySingleUsePassowordInteger = null;
      try {
         mySingleUsePassowordInteger = new Integer(Integer.parseInt(mySingleUsePassword));
      }
      catch (NumberFormatException e) {
      }
      assertNotNull("Single use password is not a number", mySingleUsePassowordInteger);
   }
}
